# /u/sy/beebe/tex/bib/iso8859-1-to-tex.awk, Fri Nov 20 09:14:30 1998
# Edit by Nelson H. F. Beebe <beebe@math.utah.edu>
# ========================================================================
# Convert an input stream containing ISO 8859-1 encoding characters
# in 128..255 to TeX equivalents in ASCII.  Characters 0..127 are
# preserved as normal ASCII.
#
# Usage:
#	gawk -f iso8859-1-to-tex.awk infile(s) >outfile
#
#	***************************************************************
#	* NB: Neither awk nor nawk nor mawk can be used for this job! *
#	***************************************************************
#
# [11-Oct-2000] -- add translation of apostrophe (222#8)
# [20-Nov-1998]
# ========================================================================

# Most lines probably do not need filtering, so checking with a single
# pattern saves a lot of time
/[\200-\377]/	{ print iso8859_1_to_tex($0); next }

		{ print }

# ========================================================================

function iso8859_1_to_tex(s)
{
    # From P. Flynn, The WorldWideWeb Handbook, p. 170, Table 8.2

    gsub("",	"\\nbsp{}",	s) 	# &nbsp;	[non-standard TeX: could use ~]
    gsub("",	"`!",		s)	# &iexcl;
    gsub("",	"\\cents{}",	s)	# &cent;
    gsub("",	"\\pounds{}",	s)	# &pound;
    gsub("",	"\\currency{}",	s)	# &curren;	[non-standard TeX]
    gsub("",	"\\yen{}",	s)	# &yen;		[non-standard TeX]
    gsub("",	"\\brvbar{}",	s)	# &brvbar;	[non-standard TeX]
    gsub("",	"\\S{}",	s)	# &sect;
    gsub("",	"\\\"",		s)	# &uml;
    gsub("",	"\\copyright{}",	s)	# &copy;
    gsub("",	"${}^a$",	s)	# &ordf;
    gsub("",	"\\og",		s) 	# &laquo;	[ouvrez guillemet] [French TeX]
    gsub("",	"\\isonot{}",	s) 	# &not;		[non-standard TeX]
    gsub("",	"{\\-}",	s)	# &shy;
    gsub("",	"\\reg{}",	s)	# &reg;		[non-standard TeX]
    gsub("",	"\\=",		s)	# &macr;
    gsub("",	"${}^\\circ$",	s)	# &deg;
    gsub("",	"\\pm{}",	s)	# &plusmn;
    gsub("",	"$^{}^2$",	s)	# &sup2;
    gsub("",	"$^{}^3$",	s)	# &sup3;
    gsub("",	"\\'",		s)	# &acute;
    gsub("",	"\\micro{}",	s)	# &micro;	[non-standard TeX]
    gsub("",	"\\P{}",	s)	# &para;
    gsub("",	"$\\cdot$",	s)	# &middot;
    gsub("",	"\\c ",		s)	# &cedil;
    gsub("",	"$^{}^1$",	s)	# &sup1;
    gsub("",	"${}^o$",	s)	# &ordm;
    gsub("",	"\\fg{}",	s)	# &raquo;	[fermez guillemet] [French TeX]
    gsub("",	"$1/4$",	s)	# &frac14;
    gsub("",	"$1/2$",	s)	# &frac12;
    gsub("",	"$3/4$",	s)	# &frac34;
    gsub("",	"`?",		s)	# &iquest;

    gsub("","'",		s)	# apostrophe

    # Table borrowed from /u/sy/beebe/public_html/support/darmstadt/sgml/psgml/iso88591.map
    # See also UNIX /usr/pub/iso

    gsub("\300",	"{\\`A}",	s)	# &Agrave;
    gsub("\301",	"{\\'A}",	s)	# &Aacute;
    gsub("\302",	"{\\^A}",	s)	# &Acirc;
    gsub("\303",	"{\\~A}",	s)	# &Atilde;
    gsub("\304",	"{\\\"A}",	s)	# &Auml;
    gsub("\305",	"{\\AA}",	s)	# &Aring;
    gsub("\306",	"{\\AE}",	s)	# &AElig;
    gsub("\307",	"{\\c{C}}",	s)	# &Ccedil;
    gsub("\310",	"{\\`E}",	s)	# &Egrave;
    gsub("\311",	"{\\'E}",	s)	# &Eacute;
    gsub("\312",	"{\\^E}",	s)	# &Ecirc;
    gsub("\313",	"{\\\"E}",	s)	# &Euml;
    gsub("\314",	"{\\`I}",	s)	# &Igrave;
    gsub("\315",	"{\\'I}",	s)	# &Iacute;
    gsub("\316",	"{\\^I}",	s)	# &Icirc;
    gsub("\317",	"{\\\"I}",	s)	# &Iuml;
    gsub("\320",	"{\\Eth}",	s)	# &ETH;
    gsub("\321",	"{\\~N}",	s)	# &Ntilde;
    gsub("\322",	"{\\`O}",	s)	# &Ograve;
    gsub("\323",	"{\\'O}",	s)	# &Oacute;
    gsub("\324",	"{\\^O}",	s)	# &Ocirc;
    gsub("\325",	"{\\~O}",	s)	# &Otilde;
    gsub("\326",	"{\\\"O}",	s)	# &Ouml;

    gsub("\327",	"$\\times$",	s)	# Multiply sign (missing from iso88591.map)

    gsub("\330",	"{\\O}",	s)	# &Oslash;
    gsub("\331",	"{\\`U}",	s)	# &Ugrave;
    gsub("\332",	"{\\'U}",	s)	# &Uacute;
    gsub("\333",	"{\\^U}",	s)	# &Ucirc;
    gsub("\334",	"{\\\"U}",	s)	# &Uuml;
    gsub("\335",	"{\\'Y}",	s)	# &Yacute;
    gsub("\336",	"{\\Thorn}",	s)	# &THORN;
    gsub("\337",	"{\\ss}",	s)	# &szlig;
    gsub("\340",	"{\\`a}",	s)	# &agrave;
    gsub("\341",	"{\\'a}",	s)	# &aacute;
    gsub("\342",	"{\\^a}",	s)	# &acirc;
    gsub("\343",	"{\\~a}",	s)	# &atilde;
    gsub("\344",	"{\\\"a}",	s)	# &auml;
    gsub("\345",	"{\\aa}",	s)	# &aring;
    gsub("\346",	"{\\ae}",	s)	# &aelig;
    gsub("\347",	"{\\c{c}}",	s)	# &ccedil;
    gsub("\350",	"{\\`e}",	s)	# &egrave;
    gsub("\351",	"{\\'e}",	s)	# &eacute;
    gsub("\352",	"{\\^e}",	s)	# &ecirc;
    gsub("\353",	"{\\\"e}",	s)	# &euml;
    gsub("\354",	"{\\`\\i}",	s)	# &igrave;
    gsub("\355",	"{\\'\\i}",	s)	# &iacute;
    gsub("\356",	"{\\^\\i}",	s)	# &icirc;
    gsub("\357",	"{\\\"\\i}",	s)	# &iuml;
    gsub("\360",	"{\\eth}",	s)	# &eth;
    gsub("\361",	"{\\~n}",	s)	# &ntilde;
    gsub("\362",	"{\\`o}",	s)	# &ograve;
    gsub("\363",	"{\\'o}",	s)	# &oacute;
    gsub("\364",	"{\\^o}",	s)	# &ocirc;
    gsub("\365",	"{\\~o}",	s)	# &otilde;
    gsub("\366",	"{\\\"o}",	s)	# &ouml;

    gsub("\367",	"$\\div$",	s)	# Division sign (missing from iso88591.map)

    gsub("\370",	"{\\o}",	s)	# &oslash;
    gsub("\371",	"{\\`u}",	s)	# &ugrave;
    gsub("\372",	"{\\'u}",	s)	# &uacute;
    gsub("\373",	"{\\^u}",	s)	# &ucirc;
    gsub("\374",	"{\\\"u}",	s)	# &uuml;
    gsub("\375",	"{\\'y}",	s)	# &yacute;
    gsub("\376",	"{\\thorn}",	s)	# &thorn;
    gsub("\377",	"{\\\"y}",	s)	# &yuml;

    return (s)
}
